ToBytes

Trait ToBytes 

pub trait ToBytes: Sealed {
    type Bytes: Copy + Unpin + Send + Sync + AsRef<[u8]> + AsMut<[u8]> + SimdUint<Scalar = u8> + 'static;

    // Required methods
    fn to_ne_bytes(self) -> Self::Bytes;
    fn to_be_bytes(self) -> Self::Bytes;
    fn to_le_bytes(self) -> Self::Bytes;
    fn from_ne_bytes(bytes: Self::Bytes) -> Self;
    fn from_be_bytes(bytes: Self::Bytes) -> Self;
    fn from_le_bytes(bytes: Self::Bytes) -> Self;
}
🔬This is a nightly-only experimental API. (portable_simd #86656)
Converts SIMD vectors to vectors of bytes

Required Associated Types

type Bytes: Copy + Unpin + Send + Sync + AsRef<[u8]> + AsMut<[u8]> + SimdUint<Scalar = u8> + 'static

🔬This is a nightly-only experimental API. (portable_simd #86656)

This type, reinterpreted as bytes.

Required Methods

fn to_ne_bytes(self) -> Self::Bytes

🔬This is a nightly-only experimental API. (portable_simd #86656)

Returns the memory representation of this integer as a byte array in native byte order.

fn to_be_bytes(self) -> Self::Bytes

🔬This is a nightly-only experimental API. (portable_simd #86656)

Returns the memory representation of this integer as a byte array in big-endian (network) byte order.

fn to_le_bytes(self) -> Self::Bytes

🔬This is a nightly-only experimental API. (portable_simd #86656)

Returns the memory representation of this integer as a byte array in little-endian byte order.

fn from_ne_bytes(bytes: Self::Bytes) -> Self

🔬This is a nightly-only experimental API. (portable_simd #86656)

Creates a native endian integer value from its memory representation as a byte array in native endianness.

fn from_be_bytes(bytes: Self::Bytes) -> Self

🔬This is a nightly-only experimental API. (portable_simd #86656)

Creates an integer value from its representation as a byte array in big endian.

fn from_le_bytes(bytes: Self::Bytes) -> Self

🔬This is a nightly-only experimental API. (portable_simd #86656)

Creates an integer value from its representation as a byte array in little endian.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl ToBytes for Simd<f32, 1>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<f32, 2>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<f32, 4>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<f32, 8>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<f32, 16>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<f64, 1>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<f64, 2>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<f64, 4>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<f64, 8>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i8, 1>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i8, 2>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i8, 4>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i8, 8>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i8, 16>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i8, 32>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i8, 64>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i16, 1>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i16, 2>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i16, 4>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i16, 8>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i16, 16>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i16, 32>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i32, 1>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i32, 2>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i32, 4>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i32, 8>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i32, 16>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i64, 1>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i64, 2>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i64, 4>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<i64, 8>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<isize, 1>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<isize, 2>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<isize, 4>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<isize, 8>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u8, 1>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u8, 2>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u8, 4>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u8, 8>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u8, 16>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u8, 32>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u8, 64>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u16, 1>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u16, 2>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u16, 4>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u16, 8>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u16, 16>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u16, 32>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u32, 1>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u32, 2>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u32, 4>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u32, 8>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u32, 16>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u64, 1>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u64, 2>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u64, 4>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<u64, 8>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<usize, 1>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<usize, 2>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<usize, 4>

Source

type Bytes = Simd<u8, { $size * $elems }>

Source

impl ToBytes for Simd<usize, 8>

Source

type Bytes = Simd<u8, { $size * $elems }>